% sediment transport modeling PS 1
% question 2d
% william armstrong
% 28 january 2013

%initializing
h0 = 0; % starting lake height [m]
alpha = 4*((2*pi/360)); % basin slope [rad]
r0 = h0/tan(alpha); % starting lake radius [m]
v0 = (1/3)*pi*h0*r0^2; % starting lake volume [m^3]
z0 = 1E3; % basin elevation [m]
a0 = pi*r0^2; % starting lake area [m^2]
precip = 0.1; % precip rate [m a^-1]
evap = 2.5; % evap rate [m a^-1]
runRat = 0.5; % runoff coefficient [unitless]

aB = 1E9; % basin area [m^2]
R = sqrt(aB/pi); % basin radius [m]

% initializing temporal & spatial variables
dt = 1E-1; % time step [annum]
tf = 3E2; % end time [annum]
t = 0:dt:tf;
hOld = h0;
zOld = z0;
rOld = r0;
vOld = v0;
aOld = a0;
hVec = []; % initializing vectors to store time series
zVec = [];
rVec = [];
vVec = [];
aVec = [];


for i = 1:length(t)
    dV = (precip*pi*rOld^2 + precip*runRat*pi*(R^2 - rOld^2) - evap*pi*rOld^2)*dt; % change in lake volume with each time step
    vNew = vOld + dV; % calculating new lake volume
    rNew = ((3*vNew)/(pi*tan(alpha)))^(1/3); % calculating lake radius from lake volume
    hNew = (3*vNew)/(pi*rNew^2); % calculating water level from radius and volume
    zNew = hNew + z0;
    aNew = pi*rNew^2;
    vVec = [vVec vNew]; % storing variables
    rVec = [rVec rNew];
    hVec = [hVec hNew];
    zVec = [zVec zNew];
    aVec = [aVec aNew];
    vOld = vNew;
    rOld = rNew;
end

vSS = vVec(end);
hSS = hVec(end);
aSS = aVec(end);
vChar = vSS - (vSS/exp(1)); % calculating characteristic values of spatial parameters
aChar = aSS - (aSS/exp(1));
hChar = hSS - (hSS/exp(1));
tvChar = t(min(find(vVec>vChar))); % approximating characteristic timescales
taChar = t(min(find(aVec>aChar)));
thChar = t(min(find(hVec>hChar)));

% plotting
clf
figure(1)
orient landscape
subplot(3,1,1)
plot(t,vVec)
hold on
plot([get(gca,'Xlim')], [vChar vChar],'--')
plot([tvChar tvChar], [get(gca,'Ylim')],'--')
title('Model 1, question 2d -- Closed lake hydrologic history; increasing volume','fontname','arial','fontsize',20)
ylabel('Lake volume [m^3]','fontname','arial','fontsize',16)
legend('volume','characteristic scale','location','southeast')
subplot(3,1,2)
plot(t,aVec)
hold on
plot([get(gca,'Xlim')], [aChar aChar],'--')
plot([taChar taChar], [get(gca,'Ylim')],'--')
ylabel('Lake area [m^2]','fontname','arial','fontsize',16)
legend('area','characteristic scale','location','southeast')
subplot(3,1,3)
plot(t,hVec+z0)
hold on
plot([get(gca,'Xlim')], [hChar+z0 hChar+z0],'--')
plot([thChar thChar], [get(gca,'Ylim')],'--')
legend('elevation','characteristic scale','location','southeast')
ylabel('Lake surface elevation [m]','fontname','arial','fontsize',16)
xlabel('Time [years]','fontname','arial','fontsize',18)

